==> zio-aws-mturk_2.13-5.17.152.1-sources.jar: zio/aws/mturk/model/CreateQualificationTypeResponse.scala <==
package zio.aws.mturk.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateQualificationTypeResponse(
    qualificationType: Option[zio.aws.mturk.model.QualificationType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mturk.model.CreateQualificationTypeResponse = {
    import CreateQualificationTypeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mturk.model.CreateQualificationTypeResponse
      .builder()
      .optionallyWith(qualificationType.map(value => value.buildAwsValue()))(
        _.qualificationType
      )
      .build()
  }
  def asReadOnly: zio.aws.mturk.model.CreateQualificationTypeResponse.ReadOnly =
    zio.aws.mturk.model.CreateQualificationTypeResponse.wrap(buildAwsValue())
}
object CreateQualificationTypeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mturk.model.CreateQualificationTypeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mturk.model.CreateQualificationTypeResponse =
      zio.aws.mturk.model.CreateQualificationTypeResponse(
        qualificationType.map(value => value.asEditable)
      )
    def qualificationType
        : Option[zio.aws.mturk.model.QualificationType.ReadOnly]
    def getQualificationType
        : ZIO[Any, AwsError, zio.aws.mturk.model.QualificationType.ReadOnly] =
      AwsError.unwrapOptionField("qualificationType", qualificationType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mturk.model.CreateQualificationTypeResponse
  ) extends zio.aws.mturk.model.CreateQualificationTypeResponse.ReadOnly {
    override val qualificationType
        : Option[zio.aws.mturk.model.QualificationType.ReadOnly] = scala
      .Option(impl.qualificationType())
      .map(value => zio.aws.mturk.model.QualificationType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mturk.model.CreateQualificationTypeResponse
  ): zio.aws.mturk.model.CreateQualificationTypeResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mturk_2.13-5.17.169.1-sources.jar: zio/aws/mturk/model/CreateQualificationTypeResponse.scala <==
package zio.aws.mturk.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateQualificationTypeResponse(
    qualificationType: Optional[zio.aws.mturk.model.QualificationType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mturk.model.CreateQualificationTypeResponse = {
    import CreateQualificationTypeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mturk.model.CreateQualificationTypeResponse
      .builder()
      .optionallyWith(qualificationType.map(value => value.buildAwsValue()))(
        _.qualificationType
      )
      .build()
  }
  def asReadOnly: zio.aws.mturk.model.CreateQualificationTypeResponse.ReadOnly =
    zio.aws.mturk.model.CreateQualificationTypeResponse.wrap(buildAwsValue())
}
object CreateQualificationTypeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mturk.model.CreateQualificationTypeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mturk.model.CreateQualificationTypeResponse =
      zio.aws.mturk.model.CreateQualificationTypeResponse(
        qualificationType.map(value => value.asEditable)
      )
    def qualificationType
        : Optional[zio.aws.mturk.model.QualificationType.ReadOnly]
    def getQualificationType
        : ZIO[Any, AwsError, zio.aws.mturk.model.QualificationType.ReadOnly] =
      AwsError.unwrapOptionField("qualificationType", qualificationType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mturk.model.CreateQualificationTypeResponse
  ) extends zio.aws.mturk.model.CreateQualificationTypeResponse.ReadOnly {
    override val qualificationType
        : Optional[zio.aws.mturk.model.QualificationType.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.qualificationType())
        .map(value => zio.aws.mturk.model.QualificationType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mturk.model.CreateQualificationTypeResponse
  ): zio.aws.mturk.model.CreateQualificationTypeResponse.ReadOnly = new Wrapper(
    impl
  )
}
